@@ -37,6 +37,8 @@ void K3b::addDefaultPrograms( K3b::ExternalBinManager* m )
 // https://bugs.kde.org/show_bug.cgi?id=381131
 void K3b::addTranscodePrograms(K3b::ExternalBinManager* m)
 {
+    Q_UNUSED(m);
+    /* Deprecated transcode
     static const char* const transcodeTools[] =  {"transcode",
                                              0, // K3b 1.0 only uses the transcode binary
                                              "tcprobe",
@@ -48,6 +50,7 @@ void K3b::addTranscodePrograms(K3b::ExternalBinManager* m)
 
     for (int i = 0; transcodeTools[i]; ++i)
         m->addProgram(new K3b::TranscodeProgram(transcodeTools[i]));
+    */
 }
 
 
